@@ -43,21 +43,18 @@ extern "C" {
 struct connman_storage {
 	const char *name;
 	int priority;
+	int (*global_load) (void);
+	int (*global_save) (void);
 	enum connman_device_type device_type;
-	int (*device_init) (void);
 	int (*device_load) (struct connman_device *device);
 	int (*device_save) (struct connman_device *device);
-	enum connman_network_type network_type;
-	int (*network_init) (struct connman_device *device);
-	int (*network_load) (struct connman_network *network);
-	int (*network_save) (struct connman_network *network);
 	enum connman_service_type service_type;
 	int (*service_load) (struct connman_service *service);
 	int (*service_save) (struct connman_service *service);
 };
 
-extern int connman_storage_register(struct connman_storage *storage);
-extern void connman_storage_unregister(struct connman_storage *storage);
+int connman_storage_register(struct connman_storage *storage);
+void connman_storage_unregister(struct connman_storage *storage);
 
 #ifdef __cplusplus
 }
