@@ -39,6 +39,8 @@ DBusMessage *__connman_error_not_supported(DBusMessage *msg);
 DBusMessage *__connman_error_not_implemented(DBusMessage *msg);
 DBusMessage *__connman_error_no_carrier(DBusMessage *msg);
 DBusMessage *__connman_error_in_progress(DBusMessage *msg);
+DBusMessage *__connman_error_already_enabled(DBusMessage *msg);
+DBusMessage *__connman_error_already_disabled(DBusMessage *msg);
 DBusMessage *__connman_error_already_connected(DBusMessage *msg);
 DBusMessage *__connman_error_not_connected(DBusMessage *msg);
 DBusMessage *__connman_error_operation_aborted(DBusMessage *msg);
@@ -172,10 +174,10 @@ struct connman_device *__connman_element_get_device(struct connman_element *elem
 const char *__connman_element_get_device_path(struct connman_element *element);
 const char *__connman_element_get_network_path(struct connman_element *element);
 
-struct connman_device *__connman_element_find_device(enum connman_device_type type);
-int __connman_element_request_scan(enum connman_device_type type);
-int __connman_element_enable_technology(enum connman_device_type type);
-int __connman_element_disable_technology(enum connman_device_type type);
+struct connman_device *__connman_element_find_device(enum connman_service_type type);
+int __connman_element_request_scan(enum connman_service_type type);
+int __connman_element_enable_technology(enum connman_service_type type);
+int __connman_element_disable_technology(enum connman_service_type type);
 
 const char *__connman_element_type2string(enum connman_element_type type);
 
@@ -201,9 +203,11 @@ void __connman_connection_cleanup(void);
 gboolean __connman_connection_update_gateway(void);
 
 int __connman_udev_init(void);
+void __connman_udev_start(void);
 void __connman_udev_cleanup(void);
 char *__connman_udev_get_devtype(const char *ifname);
 char *__connman_udev_get_mbm_devnode(const char *ifname);
+void __connman_udev_rfkill(const char *sysname, connman_bool_t blocked);
 
 #include <connman/device.h>
 
@@ -212,6 +216,13 @@ void __connman_device_cleanup(void);
 
 enum connman_service_type __connman_device_get_service_type(struct connman_device *device);
 
+int __connman_device_get_phyindex(struct connman_device *device);
+void __connman_device_set_phyindex(struct connman_device *device,
+							int phyindex);
+int __connman_device_set_blocked(struct connman_device *device,
+						connman_bool_t blocked);
+
+
 void __connman_device_increase_connections(struct connman_device *device);
 void __connman_device_decrease_connections(struct connman_device *device);
 
@@ -308,9 +319,12 @@ void __connman_notifier_connect(enum connman_service_type type);
 void __connman_notifier_disconnect(enum connman_service_type type);
 void __connman_notifier_offlinemode(connman_bool_t enabled);
 
+connman_bool_t __connman_notifier_is_enabled(enum connman_service_type type);
+
 #include <connman/rtnl.h>
 
 int __connman_rtnl_init(void);
+void __connman_rtnl_start(void);
 void __connman_rtnl_cleanup(void);
 
 int __connman_rtnl_send(const void *buf, size_t len);
